==> yawp-1.21.4-fabric-0.5.2-beta1-sources.jar: de/z0rdak/yawp/commands/arguments/ArgumentUtil.java <==
package de.z0rdak.yawp.commands.arguments;

import com.mojang.brigadier.arguments.BoolArgumentType;
import com.mojang.brigadier.arguments.IntegerArgumentType;
import com.mojang.brigadier.arguments.StringArgumentType;
import com.mojang.brigadier.builder.LiteralArgumentBuilder;
import com.mojang.brigadier.context.CommandContext;
import com.mojang.brigadier.exceptions.CommandSyntaxException;
import de.z0rdak.yawp.api.commands.CommandConstants;
import de.z0rdak.yawp.commands.arguments.flag.IFlagArgumentType;
import de.z0rdak.yawp.commands.arguments.flag.RegionFlagArgumentType;
import de.z0rdak.yawp.commands.arguments.region.ContainingOwnedRegionArgumentType;
import de.z0rdak.yawp.commands.arguments.region.RegionArgumentType;
import de.z0rdak.yawp.constants.Constants;
import de.z0rdak.yawp.core.area.AreaType;
import de.z0rdak.yawp.core.flag.FlagState;
import de.z0rdak.yawp.core.flag.FlagType;
import de.z0rdak.yawp.core.flag.IFlag;
import de.z0rdak.yawp.core.flag.RegionFlag;
import de.z0rdak.yawp.core.region.*;
import de.z0rdak.yawp.data.region.DimensionRegionCache;
import de.z0rdak.yawp.data.region.RegionDataManager;
import org.jetbrains.annotations.Nullable;

import java.util.Arrays;
import java.util.Collection;
import java.util.List;
import java.util.Set;
import net.minecraft.class_2168;
import net.minecraft.class_2170;
import net.minecraft.class_2186;
import net.minecraft.class_2243;
import net.minecraft.class_270;
import net.minecraft.class_3222;
import net.minecraft.class_5242;

import static de.z0rdak.yawp.api.commands.CommandConstants.*;

public class ArgumentUtil {

    public static LiteralArgumentBuilder<class_2168> literal(CommandConstants constant) {
        return class_2170.method_9247(constant.toString());
    }

    public static DimensionRegionCache getDimCacheArgument(CommandContext<class_2168> ctx) {
        try {
            return DimensionCacheArgumentType.getDimRegion(ctx, CommandConstants.DIM.toString());
        } catch (CommandSyntaxException e) {
            Constants.LOGGER.error(e.getMessage());
            throw new RuntimeException(e);
        }
    }

    public static DimensionalRegion getDimRegionFromArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return DimensionCacheArgumentType.getDimRegion(ctx, CommandConstants.DIM.toString()).getDimensionalRegion();
    }

    public static GlobalRegion getGlobalRegion() {
        return RegionDataManager.get().getGlobalRegion();
    }

    public static AreaType getAreaTypeArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return AreaArgumentType.getAreaType(ctx);
    }

    public static String getRegionNameArgument(CommandContext<class_2168> ctx) {
        return StringArgumentType.getString(ctx, CommandConstants.NAME.toString());
    }

    public static IMarkableRegion getRegionArgument(CommandContext<class_2168> ctx) {
        try {
            return RegionArgumentType.getRegion(ctx, LOCAL.toString());
        } catch (CommandSyntaxException e) {
            Constants.LOGGER.error(e.getMessage());
            throw new RuntimeException(e);
        }
    }

    public static IProtectedRegion getRegion(CommandContext<class_2168> ctx, RegionType regionType) throws CommandSyntaxException {
        return RegionArgumentType.getRegion(ctx, regionType);
    }

    public static IProtectedRegion getTargetLocalRegionArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return RegionArgumentType.getTargetRegion(ctx, TARGET_REGION.toString());
    }

    public static DimensionRegionCache getTargetDimRegionArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return DimensionCacheArgumentType.getDimRegion(ctx, TARGET_DIM.toString());
    }


    public static IMarkableRegion getChildRegionArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return RegionArgumentType.getRegion(ctx, CHILD.toString());
    }

    public static IMarkableRegion getContainingOwnedRegionArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return ContainingOwnedRegionArgumentType.getRegion(ctx, PARENT.toString());
    }

    public static IMarkableRegion getContainingOwnedRegionArgumentWithMarker(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return ContainingOwnedRegionArgumentType.getRegionWithMarker(ctx, PARENT.toString());
    }

    public static class_3222 getPlayerArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return class_2186.method_9315(ctx, CommandConstants.PLAYER.toString());
    }

    public static Collection<class_3222> getPlayersArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return class_2186.method_9312(ctx, CommandConstants.PLAYER.toString());
    }

    public static java.util.UUID getPlayerUUIDArgument(CommandContext<class_2168> ctx) {
        return class_5242.method_27645(ctx, CommandConstants.PLAYER_UUID.toString());
    }

    public static List<String> getPlayerNamesArgument(CommandContext<class_2168> ctx) {
        String[] names = StringArgumentType.getString(ctx, PLAYER_NAMES.toString()).split(" ");
        return Arrays.asList(names);
    }

    public static String getFlagNameArgument(CommandContext<class_2168> ctx) {
        return StringArgumentType.getString(ctx, CommandConstants.FLAG.toString());
    }

    public static RegionFlag getFlagArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return RegionFlagArgumentType.getFlag(ctx, CommandConstants.FLAG.toString());
    }

    public static Set<RegionFlag> getFlagArguments(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return RegionFlagArgumentType.getFlags(ctx, CommandConstants.FLAGS.toString());
    }

    @Nullable
    public static IFlag getIFlagArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return IFlagArgumentType.getFlag(ctx, CommandConstants.FLAG.toString());
    }

    public static String getFlagMsgArgument(CommandContext<class_2168> ctx) {
        return StringArgumentType.getString(ctx, CommandConstants.MSG.toString());
    }

    public static FlagType getFlagTypeArgument(CommandContext<class_2168> ctx) {
        return FlagType.of(StringArgumentType.getString(ctx, CommandConstants.TYPE.toString()));
    }

    public static String getGroupArgument(CommandContext<class_2168> ctx) {
        return StringArgumentType.getString(ctx, CommandConstants.GROUP.toString());
    }

    public static class_3222 getOwnerArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return class_2186.method_9315(ctx, CommandConstants.OWNER.toString());
    }

    public static class_270 getTeamArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return class_2243.method_9480(ctx, CommandConstants.TEAM.toString());
    }

    public static boolean getAlertArgument(CommandContext<class_2168> ctx) {
        return BoolArgumentType.getBool(ctx, CommandConstants.ALERT.toString());
    }

    public static boolean muteArgument(CommandContext<class_2168> ctx) {
        return BoolArgumentType.getBool(ctx, CommandConstants.MUTE.toString());
    }


    public static boolean getEnableArgument(CommandContext<class_2168> ctx) {
        return BoolArgumentType.getBool(ctx, CommandConstants.ENABLE.toString());
    }

    public static FlagState getFlagStateArgument(CommandContext<class_2168> ctx) {
        String state = StringArgumentType.getString(ctx, STATE.toString());
        return FlagState.from(state);
    }

    public static boolean getOverrideArgument(CommandContext<class_2168> ctx) {
        return BoolArgumentType.getBool(ctx, CommandConstants.OVERRIDE.toString());
    }

    public static int getPriorityArgument(CommandContext<class_2168> ctx) {
        return IntegerArgumentType.getInteger(ctx, CommandConstants.PRIORITY.toString());
    }

    public static int getPageNoArgument(CommandContext<class_2168> ctx) {
        return IntegerArgumentType.getInteger(ctx, PAGE.toString());
    }

    public static String revertCommand(String cmd, CommandConstants toReplace, CommandConstants reverted) {
        String revertedCmd = cmd.replace(toReplace.toString(), reverted.toString());
        return cmd.startsWith("/") ? revertedCmd : "/" + revertedCmd;
    }

    public static String revertCommand(String cmd, String toReplace, String reverted) {
        String revertedCmd = cmd.replace(toReplace, reverted);
        return cmd.startsWith("/") ? revertedCmd : "/" + revertedCmd;
    }
}

==> yawp-1.21.5-fabric-0.5.3-beta1-sources.jar: de/z0rdak/yawp/commands/arguments/ArgumentUtil.java <==
package de.z0rdak.yawp.commands.arguments;

import com.mojang.brigadier.arguments.BoolArgumentType;
import com.mojang.brigadier.arguments.IntegerArgumentType;
import com.mojang.brigadier.arguments.StringArgumentType;
import com.mojang.brigadier.builder.LiteralArgumentBuilder;
import com.mojang.brigadier.context.CommandContext;
import com.mojang.brigadier.exceptions.CommandSyntaxException;
import de.z0rdak.yawp.api.commands.CommandConstants;
import de.z0rdak.yawp.api.core.RegionManager;
import de.z0rdak.yawp.commands.arguments.flag.IFlagArgumentType;
import de.z0rdak.yawp.commands.arguments.flag.RegionFlagArgumentType;
import de.z0rdak.yawp.commands.arguments.region.ContainingOwnedRegionArgumentType;
import de.z0rdak.yawp.commands.arguments.region.RegionArgumentType;
import de.z0rdak.yawp.constants.Constants;
import de.z0rdak.yawp.core.area.AreaType;
import de.z0rdak.yawp.core.flag.FlagState;
import de.z0rdak.yawp.core.flag.FlagType;
import de.z0rdak.yawp.core.flag.IFlag;
import de.z0rdak.yawp.core.flag.RegionFlag;
import de.z0rdak.yawp.core.region.*;
import de.z0rdak.yawp.data.region.LevelRegionData;
import org.jetbrains.annotations.Nullable;

import java.util.Arrays;
import java.util.Collection;
import java.util.List;
import java.util.Set;
import net.minecraft.class_2168;
import net.minecraft.class_2170;
import net.minecraft.class_2186;
import net.minecraft.class_2243;
import net.minecraft.class_270;
import net.minecraft.class_3222;
import net.minecraft.class_5242;

import static de.z0rdak.yawp.api.commands.CommandConstants.*;

public class ArgumentUtil {

    public static LiteralArgumentBuilder<class_2168> literal(CommandConstants constant) {
        return class_2170.method_9247(constant.toString());
    }

    public static LevelRegionData getLevelDataArgument(CommandContext<class_2168> ctx) {
        try {
            return LevelRegionDataArgumentType.getDimRegion(ctx, CommandConstants.DIM.toString());
        } catch (CommandSyntaxException e) {
            Constants.LOGGER.error(e.getMessage());
            throw new RuntimeException(e);
        }
    }

    public static DimensionalRegion getDimRegionFromArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return LevelRegionDataArgumentType.getDimRegion(ctx, CommandConstants.DIM.toString()).getDim();
    }

    public static GlobalRegion getGlobalRegion() {
        return RegionManager.get().getGlobalRegion();
    }

    public static AreaType getAreaTypeArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return AreaArgumentType.getAreaType(ctx);
    }

    public static String getRegionNameArgument(CommandContext<class_2168> ctx) {
        return StringArgumentType.getString(ctx, CommandConstants.NAME.toString());
    }

    public static IMarkableRegion getRegionArgument(CommandContext<class_2168> ctx) {
        try {
            return RegionArgumentType.getRegion(ctx, LOCAL.toString());
        } catch (CommandSyntaxException e) {
            Constants.LOGGER.error(e.getMessage());
            throw new RuntimeException(e);
        }
    }

    public static IProtectedRegion getRegion(CommandContext<class_2168> ctx, RegionType regionType) throws CommandSyntaxException {
        return RegionArgumentType.getRegion(ctx, regionType);
    }

    public static IProtectedRegion getTargetLocalRegionArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return RegionArgumentType.getTargetRegion(ctx, TARGET_REGION.toString());
    }

    public static LevelRegionData getTargetDimRegionArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return LevelRegionDataArgumentType.getDimRegion(ctx, TARGET_DIM.toString());
    }


    public static IMarkableRegion getChildRegionArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return RegionArgumentType.getRegion(ctx, CHILD.toString());
    }

    public static IMarkableRegion getContainingOwnedRegionArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return ContainingOwnedRegionArgumentType.getRegion(ctx, PARENT.toString());
    }

    public static IMarkableRegion getContainingOwnedRegionArgumentWithMarker(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return ContainingOwnedRegionArgumentType.getRegionWithMarker(ctx, PARENT.toString());
    }

    public static class_3222 getPlayerArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return class_2186.method_9315(ctx, CommandConstants.PLAYER.toString());
    }

    public static Collection<class_3222> getPlayersArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return class_2186.method_9312(ctx, CommandConstants.PLAYER.toString());
    }

    public static java.util.UUID getPlayerUUIDArgument(CommandContext<class_2168> ctx) {
        return class_5242.method_27645(ctx, CommandConstants.PLAYER_UUID.toString());
    }

    public static List<String> getPlayerNamesArgument(CommandContext<class_2168> ctx) {
        String[] names = StringArgumentType.getString(ctx, PLAYER_NAMES.toString()).split(" ");
        return Arrays.asList(names);
    }

    public static String getFlagNameArgument(CommandContext<class_2168> ctx) {
        return StringArgumentType.getString(ctx, CommandConstants.FLAG.toString());
    }

    public static RegionFlag getFlagArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return RegionFlagArgumentType.getFlag(ctx, CommandConstants.FLAG.toString());
    }

    public static Set<RegionFlag> getFlagArguments(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return RegionFlagArgumentType.getFlags(ctx, CommandConstants.FLAGS.toString());
    }

    @Nullable
    public static IFlag getIFlagArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return IFlagArgumentType.getFlag(ctx, CommandConstants.FLAG.toString());
    }

    public static String getFlagMsgArgument(CommandContext<class_2168> ctx) {
        return StringArgumentType.getString(ctx, CommandConstants.MSG.toString());
    }

    public static FlagType getFlagTypeArgument(CommandContext<class_2168> ctx) {
        return FlagType.of(StringArgumentType.getString(ctx, CommandConstants.TYPE.toString()));
    }

    public static String getGroupArgument(CommandContext<class_2168> ctx) {
        return StringArgumentType.getString(ctx, CommandConstants.GROUP.toString());
    }

    public static class_3222 getOwnerArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return class_2186.method_9315(ctx, CommandConstants.OWNER.toString());
    }

    public static class_270 getTeamArgument(CommandContext<class_2168> ctx) throws CommandSyntaxException {
        return class_2243.method_9480(ctx, CommandConstants.TEAM.toString());
    }

    public static boolean getAlertArgument(CommandContext<class_2168> ctx) {
        return BoolArgumentType.getBool(ctx, CommandConstants.ALERT.toString());
    }

    public static boolean muteArgument(CommandContext<class_2168> ctx) {
        return BoolArgumentType.getBool(ctx, CommandConstants.MUTE.toString());
    }


    public static boolean getEnableArgument(CommandContext<class_2168> ctx) {
        return BoolArgumentType.getBool(ctx, CommandConstants.ENABLE.toString());
    }

    public static FlagState getFlagStateArgument(CommandContext<class_2168> ctx) {
        String state = StringArgumentType.getString(ctx, STATE.toString());
        return FlagState.from(state);
    }

    public static boolean getOverrideArgument(CommandContext<class_2168> ctx) {
        return BoolArgumentType.getBool(ctx, CommandConstants.OVERRIDE.toString());
    }

    public static int getPriorityArgument(CommandContext<class_2168> ctx) {
        return IntegerArgumentType.getInteger(ctx, CommandConstants.PRIORITY.toString());
    }

    public static int getPageNoArgument(CommandContext<class_2168> ctx) {
        return IntegerArgumentType.getInteger(ctx, PAGE.toString());
    }

    public static String revertCommand(String cmd, CommandConstants toReplace, CommandConstants reverted) {
        String revertedCmd = cmd.replace(toReplace.toString(), reverted.toString());
        return cmd.startsWith("/") ? revertedCmd : "/" + revertedCmd;
    }

    public static String revertCommand(String cmd, String toReplace, String reverted) {
        String revertedCmd = cmd.replace(toReplace, reverted);
        return cmd.startsWith("/") ? revertedCmd : "/" + revertedCmd;
    }
}
